==> instabug-cordova-9.1.0.tgz: package/Escape/Sources/EscapeCore/Xamarin/XamarinPublishCommand.swift <==

//
//  PublishCommand.swift
//  Escape
//
//  Created by Aly Ezz on 10/8/19.
//
import Foundation
import SwiftCLI
import SwiftShell
import FileUtils
import PerfectMarkdown

class XamarinPublishCommand: Command {
    let name = "publish"
    let shortDescription = "Publish the xamarin nuget packages for instabug and updates the dashboard's changelog. The following environment variables are required for the command to run: DASHBOARD_TOKEN, XAMARIN_API_KEY"
    
    let projectDirectory = main.currentdirectory
    
    func execute() {
        do {
            try PackageManager.setNuggetApiKey()
            
            // Installing dependencies of Android Modules
            let androidModules = XamarinConstants.androidPackages
            for(_, androidModule) in androidModules {
                XamarinHelpers.installNugetPackages(for: androidModule, project: projectDirectory)
            }
            // Installing dependencies, packing and publishing of Android Main Module
            XamarinHelpers.pack(for: XamarinConstants.AndroidMainModule, project: projectDirectory)
            try PackageManager.publishToNugget(module:XamarinConstants.AndroidMainModule, packageID:XamarinConstants.mainAndroid)
            
            // Installing dependencies, packing and publishing of iOS Module
            XamarinHelpers.pack(for: XamarinConstants.iOSModule, project: projectDirectory)
            try PackageManager.publishToNugget(module:XamarinConstants.iOSModule, packageID:XamarinConstants.iOS)
        
            let module = XamarinConstants.iOSModule
            let moduleDirectory = projectDirectory.appending("\(module)/\(module)")
            let nuspecFileContents = Helpers.nuspecFileContents(from: moduleDirectory.appending("/\(module).nuspec"))
            let versionNumberTag = Helpers.versionNumber(from: nuspecFileContents)
            let version = "v" + Helpers.versionNumberString(from: versionNumberTag)
            try Instabug.publishToDashboard(repoAt: .xamarin, versionFrom: .none, forTargetOS: .xamarin, withVersionNumber: version)
            
        } catch {
            print(error)
            exit(1)
        }
    }
}

==> instabug-cordova-9.1.7.tgz: package/Escape/Sources/EscapeCore/Xamarin/XamarinPublishCommand.swift <==

//
//  PublishCommand.swift
//  Escape
//
//  Created by Aly Ezz on 10/8/19.
//
import Foundation
import SwiftCLI
import SwiftShell
import FileUtils
import PerfectMarkdown

class XamarinPublishCommand: Command {
    let name = "publish"
    let shortDescription = "Publish the xamarin nuget packages for instabug and updates the dashboard's changelog. The following environment variables are required for the command to run: DASHBOARD_TOKEN, XAMARIN_API_KEY"
    
    let projectDirectory = main.currentdirectory
    
    func execute() {
        do {
            try PackageManager.setNuggetApiKey()
            
            // Installing dependencies of Android Modules
            let androidModules = XamarinConstants.androidPackages
            for(_, androidModule) in androidModules {
                XamarinHelpers.installNugetPackages(for: androidModule, project: projectDirectory)
            }
            // Installing dependencies, packing and publishing of Android Main Module
            XamarinHelpers.pack(for: XamarinConstants.AndroidMainModule, project: projectDirectory)
            try PackageManager.publishToNugget(module:XamarinConstants.AndroidMainModule, packageID:XamarinConstants.mainAndroid)
            
            // Installing dependencies, packing and publishing of iOS Module
            XamarinHelpers.pack(for: XamarinConstants.iOSModule, project: projectDirectory)
            try PackageManager.publishToNugget(module:XamarinConstants.iOSModule, packageID:XamarinConstants.iOS)
            
            main.currentdirectory = projectDirectory
            
            let module = XamarinConstants.iOSModule
            let moduleDirectory = projectDirectory.appending("\(module)/\(module)")
            let nuspecFileContents = Helpers.nuspecFileContents(from: moduleDirectory.appending("/\(module).nuspec"))
            let versionNumberTag = Helpers.versionNumber(from: nuspecFileContents)
            let version = Helpers.versionNumberString(from: versionNumberTag)
            try Instabug.publishToDashboard(repoAt: .xamarin, versionFrom: .none, forTargetOS: .xamarin, withVersionNumber: version)
            
        } catch {
            print(error)
            exit(1)
        }
    }
}
